@@ -170,7 +170,7 @@ class TestBasicUseCases(TestCase):
     def testBasicCase2(self, use_groups=False):
 
         ## Test command line, config file and env var values
-        default_config_file = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        default_config_file = tempfile.NamedTemporaryFile(mode="w", delete=False)
         default_config_file.flush()
 
         p = self.initParser(default_config_files=['/etc/settings.ini',
@@ -207,7 +207,7 @@ class TestBasicUseCases(TestCase):
         self.assertParseArgsRaises("Unable to open config file: file.txt. Error: No such file or director", args="-g file.txt")
 
         # check values after setting args on command line
-        config_file2 = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        config_file2 = tempfile.NamedTemporaryFile(mode="w", delete=False)
         config_file2.flush()
 
         ns = self.parse(args="--genome hg19 -g %s bla.vcf " % config_file2.name)
@@ -347,7 +347,7 @@ class TestBasicUseCases(TestCase):
         self.assertEqual(ns.a, "positional_value")
 
     def testMutuallyExclusiveArgs(self):
-        config_file = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        config_file = tempfile.NamedTemporaryFile(mode="w", delete=False)
 
         p = self.parser
         g = p.add_argument_group(title="group1")
@@ -398,11 +398,11 @@ class TestBasicUseCases(TestCase):
         config_file.close()
 
     def testSubParsers(self):
-        config_file1 = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        config_file1 = tempfile.NamedTemporaryFile(mode="w", delete=False)
         config_file1.write("--i = B")
         config_file1.flush()
 
-        config_file2 = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        config_file2 = tempfile.NamedTemporaryFile(mode="w", delete=False)
         config_file2.write("p = 10")
         config_file2.flush()
 
@@ -627,7 +627,7 @@ class TestBasicUseCases(TestCase):
         self.initParser()
         self.add_arg("-v", "--verbose", env_var="VERBOSE", action="store_true")
         self.assertParseArgsRaises("Unexpected value for VERBOSE: 'bla'. "
-                                   "Expecting 'true', 'false', 'yes', 'no', '1' or '0'",
+                                   "Expecting 'true', 'false', 'yes', 'no', 'on', 'off', '1' or '0'",
             args="",
             env_vars={"VERBOSE" : "bla"})
         ns = self.parse("",
@@ -835,7 +835,7 @@ class TestMisc(TestCase):
         self.add_arg("--x", required=True)
 
         # verify parsing from config file
-        config_file = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        config_file = tempfile.NamedTemporaryFile(mode="w", delete=False)
         config_file.write("x=bla")
         config_file.flush()
 
@@ -847,7 +847,7 @@ class TestMisc(TestCase):
         #   args_for_setting_config_path
         #   config_arg_is_required
         #   config_arg_help_message
-        temp_cfg = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        temp_cfg = tempfile.NamedTemporaryFile(mode="w", delete=False)
         temp_cfg.write("genome=hg19")
         temp_cfg.flush()
 
@@ -861,7 +861,7 @@ class TestMisc(TestCase):
                                    "arguments are required: -c/--config",
                                    args="")
 
-        temp_cfg2 = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        temp_cfg2 = tempfile.NamedTemporaryFile(mode="w", delete=False)
         ns = self.parse("-c " + temp_cfg2.name)
         self.assertEqual(ns.genome, "hg19")
 
@@ -902,7 +902,7 @@ class TestMisc(TestCase):
         """Tests that abbreviated values don't get pulled from config file.
 
         """
-        temp_cfg = tempfile.NamedTemporaryFile(mode="w", delete=True)
+        temp_cfg = tempfile.NamedTemporaryFile(mode="w", delete=False)
         temp_cfg.write("a2a = 0.5\n")
         temp_cfg.write("a3a = 0.5\n")
         temp_cfg.flush()
@@ -934,20 +934,19 @@ class TestMisc(TestCase):
             r'usage: .* \[-h\] -c CONFIG_FILE\s+'
             r'\[-w CONFIG_OUTPUT_PATH\]\s* --arg1\s+ARG1\s*\[--flag\]\s*'
             '%s:\\s*'
-            '-h, --help \\s* show this help message and exit\n\\s*'
-            r'-c CONFIG_FILE, --config CONFIG_FILE\s+my config file\s*'
-            r'-w CONFIG_OUTPUT_PATH, --write-config CONFIG_OUTPUT_PATH\s*takes\s*'
-            r'the current command line args and writes them\s*'
-            r'out to a config file at the given path, then exits\s*'
-            r'--arg1 ARG1\s*Arg1 help text\s*'
-            r'--flag \s*Flag help text\s*'
-            'Args that start with \'--\' \\(eg. --arg1\\) can also be set in a '
-            r'config file\s*\(~/.myconfig or specified via -c\).\s*'
-            r'Config file syntax allows: key=value,\s*flag=true, stuff=\[a,b,c\] '
-            r'\(for details, see syntax at https://goo.gl/R74nmi\).\s*'
-            r'If an arg is specified in more than\s*one place, then '
-            r'commandline values\s*override config file values which override\s*'
-            r'defaults.'%OPTIONAL_ARGS_STRING
+            '-h, --help \\s* show this help message and exit '
+            r'-c CONFIG_FILE, --config CONFIG_FILE\s+my config file '
+            r'-w CONFIG_OUTPUT_PATH, --write-config CONFIG_OUTPUT_PATH takes '
+            r'the current command line args and writes them '
+            r'out to a config file at the given path, then exits '
+            r'--arg1 ARG1 Arg1 help text '
+            r'--flag Flag help text '
+            'Args that start with \'--\' can also be set in a '
+            r'config file \(~/.myconfig or specified via -c\). '
+            r'Config file syntax allows: key=value, flag=true, stuff=\[a,b,c\] '
+            r'\(for details, see syntax at https://goo.gl/R74nmi\). '
+            r'In general, command-line values override config file values '
+            r'which override defaults. '.replace(' ', '\s*') % OPTIONAL_ARGS_STRING
         )
 
     def test_FormatHelpProg(self):
@@ -974,7 +973,7 @@ class TestMisc(TestCase):
         # Test constructor args:
         #   args_for_writing_out_config_file
         #   write_out_config_file_arg_help_message
-        cfg_f = tempfile.NamedTemporaryFile(mode="w+", delete=True)
+        cfg_f = tempfile.NamedTemporaryFile(mode="w+", delete=False)
         self.initParser(args_for_writing_out_config_file=["-w"],
                         write_out_config_file_arg_help_message="write config")
 
@@ -1015,7 +1014,7 @@ class TestMisc(TestCase):
         # Test constructor args:
         #   args_for_writing_out_config_file
         #   write_out_config_file_arg_help_message
-        cfg_f = tempfile.NamedTemporaryFile(mode="w+", delete=True)
+        cfg_f = tempfile.NamedTemporaryFile(mode="w+", delete=False)
         self.initParser(args_for_writing_out_config_file=["-w"],
                         write_out_config_file_arg_help_message="write config")
 
@@ -1066,7 +1065,7 @@ class TestMisc(TestCase):
         # Test constructor args:
         #   args_for_writing_out_config_file
         #   write_out_config_file_arg_help_message
-        cfg_f = tempfile.NamedTemporaryFile(mode="w+", delete=True)
+        cfg_f = tempfile.NamedTemporaryFile(mode="w+", delete=False)
         self.initParser(args_for_writing_out_config_file=["--write-config"],
                         write_out_config_file_arg_help_message="write config")
 
@@ -1487,7 +1486,31 @@ class TestConfigFileParsers(TestCase):
 
         self.assertDictEqual(parsed_obj, {'a': '3', 'list_arg': [1,2,3]})
 
+    def testYAMLConfigFileParser_w_ArgumentParser_parsed_values(self):
+        try:
+            import yaml
+        except:
+            raise AssertionError("WARNING: PyYAML not installed. "
+                            "Couldn't test YAMLConfigFileParser")
+            return
+        
+        parser = configargparse.ArgumentParser(config_file_parser_class=configargparse.YAMLConfigFileParser)
+        parser.add_argument('-c', '--config', is_config_file=True)
+        parser.add_argument('--verbosity', action='count')
+        parser.add_argument('--verbose', action='store_true')
+        parser.add_argument('--level', type=int)
 
+        config_lines = ["verbosity: 3", 
+                        "verbose: true", 
+                        "level: 35"]
+        config_str = "\n".join(config_lines)+"\n"
+        config_file = tempfile.gettempdir()+"/temp_YAMLConfigFileParser.cfg"
+        with open(config_file, 'w') as f:
+            f.write(config_str)
+        args = parser.parse_args(["--config=%s"%config_file])
+        assert args.verbosity == 3
+        assert args.verbose == True
+        assert args.level == 35
 
 ################################################################################
 # since configargparse should work as a drop-in replacement for argparse
